@@ -1,4 +1,4 @@
-## ---- echo = FALSE, message = FALSE, warning=FALSE----------------------------
+## ----echo = FALSE, message = FALSE, warning=FALSE-----------------------------
 library(knitr)
 knitr::opts_chunk$set(
    cache = FALSE,
@@ -82,3 +82,65 @@ plot(v, yplus = .3, ylim = c(-4.5, 4), xlim = c(-4.5, 4))
 
 
 
+## ----slide-explain, echo=FALSE, fig.width = 10, fig.height = 8----------------
+par(pty="s",mfrow=c(1,2))
+rows <- 6
+m <- matrix(c(2,0,-1.5,3,4,5,4,3,-1,-2,4,-1.5),nrow=6,2)
+plot(m, xlab = "dimension 1", ylab = "dimension 2", xlim = c(-2,7), ylim = c(-2,7))
+slope <- -.45
+intercept <- 0
+negslope <- -1/slope
+abline(intercept,slope, col ="pink",lty=2)
+arrows(0,0,2,intercept+slope*2,col ="red")
+#abline(4-negslope*2,negslope)
+neginter <- m[6,2]-negslope*m[6,1]
+#abline(m[6,2]-negslope*m[6,1],negslope)
+s1 <- (intercept-neginter)/(negslope-slope)
+s2 <- intercept + s1*slope
+segments(s1,s2,m[6,1],m[6,2])
+#segments(4,3,2,4)
+for (i in 1:rows)
+{
+neginter <- m[i,2]-negslope*m[i,1]
+s1 <- (intercept-neginter)/(negslope-slope)
+s2 <- intercept + s1*slope
+segments(s1,s2,m[i,1],m[i,2],col = "blue")
+	
+}
+labels <- c("A","B","C","D","E","F")
+for (i in 1:rows)
+{
+
+text(-.15+m[i,1],.3+m[i,2],labels[i])
+}
+#
+# second application
+#
+plot(m, xlab = "dimension 1", ylab = "dimension 2", xlim = c(-2,7), ylim = c(-2,7))
+slope <- .75
+intercept <- 0
+negslope <- -1/slope
+abline(intercept,slope, col ="pink",lty=2)
+arrows(0,0,2,intercept+slope*2,col ="red")
+#abline(4-negslope*2,negslope)
+neginter <- m[6,2]-negslope*m[6,1]
+#abline(m[6,2]-negslope*m[6,1],negslope)
+s1 <- (intercept-neginter)/(negslope-slope)
+s2 <- intercept + s1*slope
+segments(s1,s2,m[6,1],m[6,2])
+#segments(4,3,2,4)
+for (i in 1:rows)
+{
+neginter <- m[i,2]-negslope*m[i,1]
+s1 <- (intercept-neginter)/(negslope-slope)
+s2 <- intercept + s1*slope
+segments(s1,s2,m[i,1],m[i,2],col = "blue")
+	
+}
+labels <- c("A","B","C","D","E","F")
+for (i in 1:rows)
+{
+
+text(.05+m[i,1],.3+m[i,2],labels[i])
+}
+
